mod roll_bot;

use structopt::StructOpt;

use std::error::Error;
use std::time::Duration;
use log::info;

use crate::roll_bot::RollBot;
use rppal::pwm::{Channel, Polarity, Pwm};

const PERIOD_MS: u64 = 20;
const PULSE_MIN_US: u64 = 1000;
const PULSE_NEUTRAL_US: u64 = 1500;
const PULSE_MAX_US: u64 = 2000;

fn main() -> Result<(), Box<dyn Error>> {
    env_logger::init();

    info!("Initializing PWM");
    let pwm = Pwm::with_period(
        Channel::Pwm0,
        Duration::from_millis(PERIOD_MS),
        Duration::from_micros(PULSE_MAX_US),
        Polarity::Normal,
        true,
    )?;

    info!("Initializing Roll Bot");
    let roll_bot = RollBot {
        pwm,
        move_time: Duration::from_millis(1000),
    };

    roll_bot.set_pwm_output(Duration::from_micros(PULSE_MIN_US))?;

    loop {
        roll_bot.roll(5)?;
        std::thread::sleep(Duration::from_millis(1000));
    }

    Ok(())
}
